[IO.Directory]::SetCurrentDirectory((Convert-Path (Get-Location -PSProvider FileSystem)))

# build the credential object
$secpasswd = ConvertTo-SecureString $args[1] -AsPlainText -Force
$credential = New-Object System.Management.Automation.PSCredential($args[0],$secpasswd);

# check if we are in the same location as the nwadmin.exe
if(Test-Path(".\nwadmin.exe"))
{ 
  # find all the workflows and store them in a variable
  $foundworkflows = .\nwadmin -o FindWorkflows

  # read the contents of the NWAdmin -o FindWorkflows
  # $foundworkflows = get-content "C:\Program Files\Nintex\Nintex Workflow 2010\workflows.txt"

  foreach($line in $foundworkflows)
  {
    if($line.StartsWith("Active at "))
    {
      # get the site url
      $site = $line.Replace("Active at ","");
    }
    if($line.StartsWith("-- "))
    { 
      # get the list name
      $list = $line.Replace("-- ","");
    }
    if($line.StartsWith("---- "))
    {
      # get the workflow name
      $workflowname = $line.Replace("---- ","");

      $webserviceurl = $site + "/_vti_bin/NintexWorkflow/Workflow.asmx"

      # get web service proxy
      $page = New-WebServiceProxy -Uri $webserviceurl -Credential $credential;
      $page.Url = $webserviceurl;

      # ($page | Get-Member -Name ExportWorkflow).definition;

      # export workflow
      try
      {
        if($list -eq "Site Workflow")
        {$exportedworkflow = $page.ExportWorkflow($workflowname,$list,'Site');}
        elseif($list -eq "Reusable workflow template")
        {$exportedworkflow = $page.ExportWorkflow($workflowname,$list,'Reusable');}
        elseif($list -eq "Site collection reusable workflow template")
        {$exportedworkflow = $page.ExportWorkflow($workflowname,$list,'GloballyReusable');}
        else
        {$exportedworkflow = $page.ExportWorkflow($workflowname,$list,'List');}
      }
      catch
      {
        echo $error;
        $exportedworkflow = "";
      }

      $localfile = "{0}\{1}.nwf" -f [IO.Directory]::GetCurrentDirectory(),$workflowname;
      echo "Exporting workflow to - " $localfile;
      $stream = [System.IO.StreamWriter] $localfile;
      $stream.WriteLine($exportedworkflow);
      $stream.close();

      # only do this for the first workflow
      # break;
    }
  }
}
else
{
  echo "NWAdmin doesn't exist.  Change directory to where NWAdmin.exe lives.";
}
